@@ -42,18 +42,18 @@ class KSaneOptSlider : public KSaneOption
 public:
     KSaneOptSlider(const SANE_Handle handle, const int index);
 
-    void createWidget(QWidget *parent) Q_DECL_OVERRIDE;
+    void createWidget(QWidget *parent) override;
 
-    void readValue() Q_DECL_OVERRIDE;
-    void readOption() Q_DECL_OVERRIDE;
+    void readValue() override;
+    void readOption() override;
 
-    bool getMinValue(float &max) Q_DECL_OVERRIDE;
-    bool getMaxValue(float &max) Q_DECL_OVERRIDE;
-    bool getValue(float &val) Q_DECL_OVERRIDE;
-    bool setValue(float val) Q_DECL_OVERRIDE;
-    bool getValue(QString &val) Q_DECL_OVERRIDE;
-    bool setValue(const QString &val) Q_DECL_OVERRIDE;
-    bool hasGui() Q_DECL_OVERRIDE;
+    bool getMinValue(float &max) override;
+    bool getMaxValue(float &max) override;
+    bool getValue(float &val) override;
+    bool setValue(float val) override;
+    bool getValue(QString &val) override;
+    bool setValue(const QString &val) override;
+    bool hasGui() override;
 
 Q_SIGNALS:
     void fValueRead(float);
